# File: UtahLevel3Ecoregions.R
# Purpose: Example area GRTS survey designs for Omernik level 3 ecoregions
#          within Utah
# Programmers: Tony Olsen and Tom Kincaid
# Date: February 28, 2005
# Last Modified: October 13, 2006

# Load the spsurvey library

library(spsurvey)

# Read the attribute table from the shapefile

att <- read.dbf("eco_l3_ut")
cat("The initial six lines in the attribute data frame follow:\n\n")
print(head(att))

# Display names of the ecoregions attribute that will be used to define
# multidensity categories (mdcaty) and strata

cat("\nNames of the Omernik Level 3 ecoregions follow:\n\n")
cat(vecprint(levels(att$LEVEL3_NAM)), "\n")

# Four example GRTS survey designs follow

# Equal probability GRTS survey design

cat("\nEqual probability GRTS survey design\n")

# Create the design list

Equaldsgn <- list(None=list(panel=c(PanelOne=115), seltype="Equal")
								)
# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Equalsites <- grts(design=Equaldsgn,
                   src.frame="shapefile",
                   in.shape="eco_l3_ut", 
                   att.frame=att,
                   type.frame="area",
                   DesignID="UTEco3EQ",
                   shapefile=TRUE,
                   prj="eco_l3_ut",
                   out.shape="Eco3.EqualSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Equalsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Equalsites))

# Unequal Probability GRTS survey design

cat("\nUnequal probability GRTS survey design\n")

# Create the design list

Unequaldsgn <- list(None=list(panel=c(PanelOne=115),
                              seltype="Unequal",
                              caty.n=c("Central Basin and Range"=25,
                                       "Colorado Plateaus"=25,
                                       "Mojave Basin and Range"=10,
                                       "Northern Basin and Range"=10,
                                       "Southern Rockies"=10,
                                       "Wasatch and Uinta Mountains"=25,
                                       "Wyoming Basin"=10)))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Unequalsites <- grts(design=Unequaldsgn,
                     src.frame="shapefile",
                     in.shape="eco_l3_ut",  
                     att.frame=att,
                     type.frame="area",
                     mdcaty="LEVEL3_NAM",									
                     DesignID="UTEco3UN",
                     shapefile=TRUE,
                     prj="eco_l3_ut",
                     out.shape="Eco3.UnEqualSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Unequalsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Unequalsites))

# Stratified GRTS survey design

cat("\nStratified GRTS survey design\n")

# Create the design list

Stratdsgn <- list("Central Basin and Range"=list(panel=c(PanelOne=25),
                                                 seltype="Equal"),
                  "Colorado Plateaus"=list(panel=c(PanelOne=25),
                                           seltype="Equal"),
                  "Mojave Basin and Range"=list(panel=c(PanelOne=10),
                                                seltype="Equal"),
                  "Northern Basin and Range"=list(panel=c(PanelOne=10),
                                                  seltype="Equal"),
                  "Southern Rockies"=list(panel=c(PanelOne=10),
                                          seltype="Equal"),
                  "Wasatch and Uinta Mountains"=list(panel=c(PanelOne=25),
                                                     seltype="Equal"),
                  "Wyoming Basin"=list(panel=c(PanelOne=10),
                                       seltype="Equal"))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Stratsites <- grts(design=Stratdsgn,
                   src.frame="shapefile",
                   in.shape="eco_l3_ut",  
                   att.frame=att,
                   type.frame="area",
                   stratum="LEVEL3_NAM",									
                   DesignID="UTEco3ST",
                   shapefile=TRUE,
                   prj="eco_l3_ut",
                   out.shape="Eco3.StratifySites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Stratsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Stratsites))

# Unequal probability GRTS survey design with an oversample and a panel
# structure for survey over time

cat("\nUnequal probability GRTS survey design with an oversample and a panel structure \nfor survey over time\n")

# Create the design list

Paneldsgn <- list(None=list(panel=c(Panel_1=50, Panel_2=50, Panel_3=50,
                                    Panel_4=50, Panel_5=50),
                            seltype="Unequal",
                            caty.n=c("Central Basin and Range"=64,
                                     "Colorado Plateaus"=63,
                                     "Mojave Basin and Range"=15,
                                     "Northern Basin and Range"=15,
                                     "Southern Rockies"=15,
                                     "Wasatch and Uinta Mountains"=63,
                                     "Wyoming Basin"=15),
                            over=100))

# Create the GRTS survey design

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
Panelsites <- grts(design=Paneldsgn,
                   src.frame="shapefile",
                   in.shape="eco_l3_ut",  
                   att.frame=att,
                   type.frame="area",
                   mdcaty="LEVEL3_NAM",									
                   DesignID="UTEco3Pan",
                   shapefile=TRUE,
                   prj="eco_l3_ut",
                   out.shape="Eco3.PanelSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(Panelsites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(Panelsites))
